@@ -4,10 +4,12 @@ package Bot::IRC::X::UriTitle;
 use strict;
 use warnings;
 
+use LWP::UserAgent;
+use LWP::Protocol::https;
 use Text::Unidecode 'unidecode';
 use URI::Title 'title';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -22,7 +24,7 @@ sub init {
 
             my %urls;
             $urls{$1} = 1 while ( $in->{text} =~ m|(https?://\S+)|g );
-            $bot->reply( '[ ' . unidecode( title($_) ) . ' ]' ) for ( keys %urls );
+            $bot->reply("[ $_ ]") for ( grep { defined } map { unidecode( title($_) ) } keys %urls );
             return;
         },
     );
@@ -42,7 +44,7 @@ Bot::IRC::X::UriTitle - Bot::IRC plugin to parse and print URI titles
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC-X-UriTitle.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC-X-UriTitle)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC-X-UriTitle/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC-X-UriTitle)
